var autoprefixer = require('gulp-autoprefixer');
var concat = require('gulp-concat');
var csso = require('gulp-csso');
var del = require('del');
var fs = require('fs');
var gulp = require('gulp');
var gutil = require('gulp-util');
var gulpFilter = require('gulp-filter');
var pureGrids = require('rework-pure-grids');
var replace = require('gulp-replace');
var rework = require('rework');
var spawn = require('child_process').spawn;
var svgSymbols = require('gulp-svg-symbols');
var webserver = require('gulp-webserver');

var paths = {
  'css': ['src/normalize.css', 'src/*.css'],
  'normalize': 'node_modules/normalize.css/normalize.css',
  'grids': 'node_modules/purecss/grids-core.css',
  'src': 'src/',
  'dest': 'public/'
};

gulp.task('default', ['build']);
// run to update Pure or normalize in ues, after 'npm update'
gulp.task('update', ['clean', 'copy', 'grids', 'build']);
gulp.task('svg', ['symbols']);

gulp.task('watch', ['build'], function() {
  gulp.watch(paths.src + '**/*.css', ['build']);
  gulp.watch([paths.normalize, paths.grids], ['copy']);
  gulp.watch('gulpfile.js', ['grids']);
});

gulp.task('build', function() {
  var filter = gulpFilter(['*.css', '!*-small.css']);
  return gulp.src(paths.css)
  .pipe(autoprefixer())
  .pipe(csso())
  .pipe(gulp.dest(paths.dest))
  .pipe(filter)
  .pipe(concat('ulysses.css'))
  .pipe(gulp.dest(paths.dest));
});

gulp.task('clean', function(cb) {
  // You can use multiple globbing patterns as you would with `gulp.src`
  del([paths.dest], cb);
});

gulp.task('copy', function() {
  gulp.src([paths.normalize, paths.grids])
  .pipe(replace(/pure-/g, 'ues-'))
  .pipe(gulp.dest(paths.src));
});

/* build the ues-g- grid from pure grids */
gulp.task('grids', function() {

  var css = rework('').use(pureGrids.units([5, 24], {
    mediaQueries: {
      sm  : 'screen and (min-width: 30em)',
      med : 'screen and (min-width: 48em)',
      lrg : 'screen and (min-width: 64em)',
      xlrg: 'screen and (min-width: 75em)'
    },
    decimals: 6,
    selectorPrefix: '.ues-u-'
  }));

  var stream = fs.createWriteStream(paths.src + 'grids-units.css');
  stream.write(css.toString());
  stream.end();

});

/* svg symbols, consider deprecating these */
gulp.task('symbols', function () {
  return gulp.src('src/icons/*.svg')
  .pipe(svgSymbols({
    css: false,
    className: '.ues-icon-%f',
  }))
  .pipe(gulp.dest('assets'));
});
